Crate logging_options

Crate logging_options 

A set of very common logging clap options which also initialize various logging/tracing backends

TODOs

  • Switch to tracing (e.g. env_logger, tracing, etc…)
  • Provide a facility to defer to the app for argument names, especially short -q style arg names to work with apps with colliding options
  • Generalize to a “re-usable component with clap arguments” framework?

Re-exports

pub use self::backend::Backend;

Modules

backend
Traits abstracting the logging Backend

Structs

StandardConsole
A bundle of clap::Args for console applications, allowing logging to stderr or a file
Verbosity
A mutually exclusive set of arguments to specify log verbosity