Backend

Trait Backend 

pub trait Backend {
    type Builder: BackendBuilder;

    // Required method
    fn builder() -> Self::Builder;

    // Provided method
    fn init_from_options<Opts>(opts: &Opts)
       where Opts: LoggingOptions<Self> { ... }
}
A logging Backend initializes and provides the actual logging functionality

Required Associated Types

Required Methods

fn builder() -> Self::Builder

Get a default-configured builder

Provided Methods

fn init_from_options<Opts>(opts: &Opts)
where Opts: LoggingOptions<Self>,

Given logging options parsed from the commandline, initialize logging

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Backend for Logger

Implementors