A set of very common logging clap options which also initialize various logging/tracing backends
TODOs
- Switch to
tracing(e.g.env_logger,tracing, etc…) - Provide a facility to defer to the app for argument names, especially short
-qstyle arg names to work with apps with colliding options - Generalize to a “re-usable component with
claparguments” framework?
Re-exports
pub use self::backend::Backend;
Modules
Structs
- Standard
Console - A bundle of clap::Args for console applications, allowing logging to stderr or a file
- Verbosity
- A mutually exclusive set of arguments to specify log verbosity