Traits abstracting the logging Backend
Applications can just use Backend::init_from_options.
New Backend impls need to also implement the other traits here.
Traits
- Backend
- A logging Backend initializes and provides the actual logging functionality
- Backend
Builder - A BackendBuilder can initialize the backend
- Logging
Options - A set of commandline options which can configure the backend