pub trait Backend {
type Builder: BackendBuilder;
// Required method
fn builder() -> Self::Builder;
// Provided method
fn init_from_options<Opts>(opts: &Opts)
where Opts: LoggingOptions<Self> { ... }
}Expand description
A logging Backend initializes and provides the actual logging functionality
Required Associated Types
Sourcetype Builder: BackendBuilder
type Builder: BackendBuilder
The BackendBuilder for Self
Required Methods
Provided Methods
Sourcefn init_from_options<Opts>(opts: &Opts)where
Opts: LoggingOptions<Self>,
fn init_from_options<Opts>(opts: &Opts)where
Opts: LoggingOptions<Self>,
Given logging options parsed from the commandline, initialize logging
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".